# Security Policy

## Supported Versions

Versions which are currently being supported with security updates:

| Version  | Supported          |
| -------- | ------------------ |
| > 1.1.0  | :white_check_mark: |

## Reporting a Vulnerability

To report a vulnerability, please create a new [*issue*](https://github.com/DerwenAI/pynock/issues).
We will be notified immediately, and will attempt to respond on the reported issue immediately.
